@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-sqlite
 version: 2.2.1
-id: persistent-sqlite-2.2.1-69de5e2e0081e61b66553a26dd3337b5
-key: persi_BiM5usmC3JrBt21i2jK864
+id: persistent-sqlite-2.2.1-528dd876cba8e032d04bda7aa027dfdb
+key: persi_EKRiMQzuroCJfNGv8Gk3xe
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,20 +20,20 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-sqlite-2.2.1
-hs-libraries: HSpersistent-sqlite-2.2.1-BiM5usmC3JrBt21i2jK864
+hs-libraries: HSpersistent-sqlite-2.2.1-EKRiMQzuroCJfNGv8Gk3xe
 extra-libraries:
     pthread
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-e41795701bd26d2e948311dc59f0bce2
+    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
+    monad-logger-0.3.18-0092336dcf2d8f29e67bd77a9cfcb547
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    persistent-2.2.4.1-515160ea71a89b76b70a56c63b058aa3
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    persistent-2.2.4.1-06cdd104cf52ce01e8563b1ef8106c7c
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
